@@ -3,7 +3,7 @@
 glance.data.frame <- function(x, ...) {
   stop(
     "There is no glance method for data frames. ",
-    "Did you mean `dplyr::glimpse()`?",
+    "Did you mean `tibble::glimpse()`?",
     call. = FALSE
   )
 }
@@ -12,7 +12,7 @@ glance.data.frame <- function(x, ...) {
 glance.tbl_df <- function(x, ...) {
   stop(
     "There is no glance method for tibbles. ",
-    "Did you mean `dplyr::glimpse()`?",
+    "Did you mean `tibble::glimpse()`?",
     call. = FALSE
   )
 }
